@@ -1,11 +1,10 @@
 from .decorators_awp import aprovarConexao
 from .errors_awp import AWPContatoNaoEncontrado
 import os
-import requests
+import re
 import time
+import requests
 import pyperclip
-import subprocess
-from PIL import Image
 from urllib import parse
 from selenium import webdriver
 from selenium.webdriver.common.by import By
@@ -90,13 +89,13 @@ class AWPMensagem():
         
         
     @aprovarConexao
-    def enviar_mensagem_compulsiva(self, recorrencia: int, iter_msg:list = []):
+    def enviar_mensagem_compulsiva(self, repeticao: int, iter_msg:list = []):
         try:
             if self.objeto_awp.InferenciaAWP.contato_acessivel:
                 self.objeto_awp.InferenciaAWP.mensagem = iter_msg
                 textbox = self.objeto_awp._ArmazemXPATH.textbox_xpath
                 
-                for i in range(recorrencia):
+                for i in range(repeticao):
                     for msg in iter_msg:
                         self.objeto_awp._drive.find_element(By.XPATH,textbox).send_keys(msg)
                 
@@ -167,13 +166,15 @@ class AWPMensagem():
             self.objeto_awp.ctt.encontrar_usuario(contato)
             
         
-        if selecionar_funcao == 1:
-            self.objeto_awp.msg.enviar_mensagem_isolada(mensagem)
+        metodos_envio:dict ={
+            1:'self.objeto_awp.msg.enviar_mensagem_isolada(mensagem)',
+            2:'self.objeto_awp.msg.enviar_mensagem_paragrafada(mensagem)',
+        }
         
-        elif selecionar_funcao == 2:
-            self.objeto_awp.msg.enviar_mensagem_paragrafada(mensagem)
-
-        else:
+        try:
+            eval(metodos_envio[selecionar_funcao])
+        except Exception as e:
+            print(e)
             raise ValueError('Valor informado incoerente.')
         
             
@@ -191,18 +192,47 @@ class AWPMensagem():
 
 
 
+class __TratarAnalise():
+    
+    def __init__(self, t_util) -> None:
+        self.__t_util = t_util
+        self.get = {
+            'USER':self.__identificar_user(),
+            'MSG':self.__identificar_mensagem(),
+            'TIME':self.__identificar_hora(),
+            'ALL':self.__t_util,
+            }
+        
+
+    def __identificar_user(self):
+        return ''
+    
+    
+    def __identificar_mensagem(self):
+        return ''
+
+
+    def __identificar_hora(self):
+        return ''
+        
+    
+
 class Analise:
     
     def __init__(self, objeto) -> None:
         self.objeto_awp = objeto
-        
+            
+    
     @aprovarConexao
     def ultima_mensagem_chat(self): #verifica se a mensagem foi enviada.
         quadro_interacao = self.objeto_awp._drive.find_element(By.XPATH, '/html/body/div[1]/div/div/div[5]/div/div[2]/div/div[2]/div[3]') #pelo quadro onde ficar as msgs
         caixa_mensagens_objeto = quadro_interacao.find_elements(By.XPATH, '//*[@role="row"]')
         caixa_mensagens = caixa_mensagens_objeto[-1].text
         
-        return caixa_mensagens  #depois aprimorar caixa_mensagens.find_element(By.XPATH, '...')
+        return __TratarAnalise(caixa_mensagens)  #depois aprimorar caixa_mensagens.find_element(By.XPATH, '...')
+        
+    
+    
         
 
 
@@ -327,4 +357,4 @@ class Anexo():
             self.objeto_awp._drive.find_element(By.XPATH, inputbox_xpath).send_keys(msg, Keys.ENTER)
         else:
             self.objeto_awp._drive.find_element(By.XPATH, inputbox_xpath).send_keys(Keys.ENTER)
-        time.sleep(1)
\ No newline at end of file
+        time.sleep(1)
